import os
from gtts import gTTS
from playsound import playsound
from datetime import datetime

def play(file):
    playsound(file, True)

def speak(text, lang = "en", slow = False, save = False, file = ""):
    dt = datetime.now().strftime("%d%m%Y%H%M%S")

    if save == True and file != "":
        file = file
    elif save == True and file == "":
        file = f"speech{dt}.mp3"
    elif save == False:
        file = f"speech{dt}.mp3"
    else:
        raise ValueError(f"'{file}' is not defined")
    
    if slow == True:
        slow = True
    elif slow ==  False:
        slow = False
    else:
        raise ValueError(f"'{slow}' is not defined")
    
    tts = gTTS(text=text, lang=lang, slow=slow)

    if os.path.splitext(file)[1] == ".mp3":
        tts.save(file)
        
        play(file)

        if save == False:
            os.unlink(file)
        elif save == True:
            pass
        else:
            raise ValueError(f"'{save}' is not defined")
    else:
        raise ValueError(f"'{file}' is not a valid mp3 format")


import setuptools

with open('README.md') as f:
    README = f.read()

setuptools.setup(
    author="Thomas Dewitte",
    author_email="thomasdewittecontact@gmail.com",

    name='text_to_speech',
    version='1.4.0',
    license="MIT",
    url='https://github.com/dewittethomas/text-to-speech',
    python_requires='>= 3.5',
    
    description='A simple text to speech engine',
    long_description=README,
    long_description_content_type="text/markdown",

    package_dir={"text_to_speech": "text_to_speech"},
    install_requires=["playsound>=1.2.2", "gTTS>=2.0.4"],
    
    packages=setuptools.find_packages(),

    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3'
    ]
)